@@ -1,9 +1,11 @@
 # -*- coding:utf-8 -*-
 # The PIGIT terminal tool entry file.
 
-from typing import List
+from typing import Dict, List
 import os, logging, textwrap
 
+from plenty import get_console
+
 from .log import setup_logging
 from .config import Config
 from .cmdparse.parser import command, argument, Namespace
@@ -18,7 +20,6 @@ from .const import (
     COUNTER_DIR_PATH,
     IS_FIRST_RUN,
 )
-from .render import get_console
 from .common.utils import confirm
 from .common.func import dynamic_default_attrs, time_it
 from .gitlib.processor import ShortGitter, GIT_CMDS, get_extra_cmds
@@ -39,7 +40,7 @@ CONFIG = Config(
 
 setup_logging(
     debug=CONFIG.debug_open,
-    log_file=LOG_FILE_PATH if CONFIG.log_output else None,
+    log_file=None if CONFIG.log_output else LOG_FILE_PATH,
 )
 
 
@@ -151,7 +152,7 @@ def _cmd_func(args: Namespace, unknown: List):
         git.add_repos([repo_path])
 
     # Init extra custom cmds.
-    extra_cmd: dict = {
+    extra_cmd: Dict = {
         # "shell": {
         #     "command": lambda _: shell_mode(git_processor),
         #     "type": "func",
